/* DNA-View - opengl.h
Here you find all definitions of OpenGL methods */

/**
Copyright (C) 2003, 2007 Dominik Wagenfuehr <dominik.wagenfuehr@arcor.de>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef OPENGL_H
#define OPENGL_H

#include <qgl.h>			// includes the QT-OpenGL-Header

class glWindow : public QGLWidget {
	Q_OBJECT

	GLfloat scale;		// scalefactor equivalent to zoomfactor
	GLfloat dist;		// distance between two bases (needed for translation)

	void genObjects(void);		// generates all objects

   public:
	glWindow( QWidget *parent=0, const char *name=0);	// standard constructor

	void setScale(GLfloat s);		// sets the scale factor

	GLfloat getScaleX(void);		// returns the x scale factor
	GLfloat getScaleY(void);		// returns the y scale factor
	GLfloat getDist(void);			// returns the distance between two bases
	GLfloat getScale(void);			// returns the scale factor
	void glTranslate(GLfloat x=0.0, GLfloat y=0.0, GLfloat z=0.0);		// translates the scene
	void glScale(GLfloat x=0.0, GLfloat y=0.0, GLfloat z=0.0);			// scales the scene
	void glRotateHalf(void);		// rotates the scene 180 degree around the z-axis (needed for 3'-5' string)

	void addA(bool rot=FALSE);		// adds standard color Adenin to the scene, rotates the char if rot==TRUE
	void addC(bool rot=FALSE);		// adds standard color Cytosin to the scene, rotates the char if rot==TRUE
	void addG(bool rot=FALSE);		// adds standard color Guanin to the scene, rotates the char if rot==TRUE
	void addT(bool rot=FALSE);		// adds standard color Thymin to the scene, rotates the char if rot==TRUE
	void addMarkedA(bool rot=FALSE);	// adds marked color Adenin to the scene, rotates the char if rot==TRUE
	void addMarkedC(bool rot=FALSE);	// adds marked color Guanin to the scene, rotates the char if rot==TRUE
	void addMarkedG(bool rot=FALSE);	// adds marked color Cytosin to the scene, rotates the char if rot==TRUE
	void addMarkedT(bool rot=FALSE);	// adds marked color Thymin to the scene, rotates the char if rot==TRUE
	void addCurrentA(bool rot=FALSE);		// adds current color Adenin to the scene, rotates the char if rot==TRUE
	void addCurrentC(bool rot=FALSE);	// adds current color Cytosin to the scene, rotates the char if rot==TRUE
	void addCurrentG(bool rot=FALSE);	// adds current color Guanin to the scene, rotates the char if rot==TRUE
	void addCurrentT(bool rot=FALSE);		// adds current color Thymin to the scene, rotates the char if rot==TRUE
	void addEmpty(void);				// adds empty base to the end

   protected:
	void initializeGL(void);			// inits the OpenGL scene
	void resizeGL(int w, int h);		// paint the OpenGL if window size is changed

   public slots:
	void paintGL(void);		// paints the OpenGL scene

   signals:
	void callScene(void);		// paints the scene with all objects later in window.cpp

};

#endif

